Module map

Type representing a Liquid object, payload of the Value::Object variant

Structs

IntoIter
An owning iterator over a liquid_core::model::Object’s entries.
Iter
An iterator over a liquid_core::model::Object’s entries.
IterMut
A mutable iterator over a liquid_core::model::Object’s entries.
Keys
An iterator over a liquid_core::model::Object’s keys.
Object
Type representing a Liquid object, payload of the Value::Object variant
OccupiedEntry
An occupied Entry. It is part of the Entry enum.
VacantEntry
A vacant Entry. It is part of the Entry enum.
Values
An iterator over a liquid_core::model::Object’s values.
ValuesMut
A mutable iterator over a liquid_core::model::Object’s values.

Enums

Entry
A view into a single entry in a map, which may either be vacant or occupied. This enum is constructed from the entry method on Object.