Module runtime

Liquid template language interpreter.

Structs

GlobalFrame
A stack frame that only provides a sandboxed set of globals
InterruptRegister
The current interrupt state. The interrupt state is used by the break and continue tags to halt template rendering at a given point and unwind the render call stack until it reaches an enclosing for_loop. At that point the interrupt is cleared, and the for_loop carries on processing as directed.
Registers
Unnamed state for plugins during rendering
RuntimeBuilder
Create processing runtime for a template.
RuntimeCore
Processing runtime for a template.
SandboxedStackFrame
A StackFrame where variables are not recursively searched for, However, you can still access the parent’s partials.
StackFrame
Layer variables on top of the existing runtime
Template
An executable template block.
Variable
A Value reference.

Enums

Expression
An un-evaluated Value.
Interrupt
Block processing interrupt state.

Traits

PartialStore
Available partial-templates for including.
Renderable
Any object (tag/block) that can be rendered by liquid must implement this trait.
Runtime
State for rendering a template