Liquid template language interpreter.
Structs
- Global
Frame - A stack frame that only provides a sandboxed set of globals
- Interrupt
Register - The current interrupt state. The interrupt state is used by
the
breakandcontinuetags to halt template rendering at a given point and unwind therendercall stack until it reaches an enclosingfor_loop. At that point the interrupt is cleared, and thefor_loopcarries on processing as directed. - Registers
- Unnamed state for plugins during rendering
- Runtime
Builder - Create processing runtime for a template.
- Runtime
Core - Processing runtime for a template.
- Sandboxed
Stack Frame - A
StackFramewhere variables are not recursively searched for, However, you can still access the parent’s partials. - Stack
Frame - Layer variables on top of the existing runtime
- Template
- An executable template block.
- Variable
- A
Valuereference.
Enums
- Expression
- An un-evaluated
Value. - Interrupt
- Block processing interrupt state.
Traits
- Partial
Store - Available partial-templates for including.
- Renderable
- Any object (tag/block) that can be rendered by liquid must implement this trait.
- Runtime
- State for rendering a template